RemoteActor

Trait RemoteActor 

pub trait RemoteActor {
    const REMOTE_ID: &'static str;
}
RemoteActor is a trait for identifying actors remotely.

Each remote actor must implement this trait and provide a unique identifier string (REMOTE_ID). The identifier is essential to distinguish between different actor types during remote communication.

Example with Derive

use kameo::{Actor, RemoteActor};

#[derive(Actor, RemoteActor)]
pub struct MyActor;

Example Manual Implementation

use kameo::remote::RemoteActor;

pub struct MyActor;

impl RemoteActor for MyActor {
    const REMOTE_ID: &'static str = "my_actor_id";
}

Required Associated Constants

const REMOTE_ID: &'static str

The remote identifier string.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors