pub struct RemoteTellRequest<'a, A, M, Tm>{ /* private fields */ }Expand description
A request to send a message to a remote actor without any reply.
This can be thought of as “fire and forget”.
Implementations
Sourceimpl<'a, A, M, Tm> RemoteTellRequest<'a, A, M, Tm>
impl<'a, A, M, Tm> RemoteTellRequest<'a, A, M, Tm>
Sourcepub fn mailbox_timeout(
self,
duration: Duration,
) -> RemoteTellRequest<'a, A, M, WithRequestTimeout>
pub fn mailbox_timeout( self, duration: Duration, ) -> RemoteTellRequest<'a, A, M, WithRequestTimeout>
Sets the timeout for waiting for the actors mailbox to have capacity.
Sourceimpl<A, M, Tm> RemoteTellRequest<'_, A, M, Tm>where
A: Actor + Message<M> + RemoteActor + RemoteMessage<M>,
M: Serialize + Send + 'static,
Tm: Into<Option<Duration>>,
impl<A, M, Tm> RemoteTellRequest<'_, A, M, Tm>where
A: Actor + Message<M> + RemoteActor + RemoteMessage<M>,
M: Serialize + Send + 'static,
Tm: Into<Option<Duration>>,
Sourcepub fn send(self) -> Result<(), RemoteSendError>
pub fn send(self) -> Result<(), RemoteSendError>
Sends the message fire-and-forget style (fast, no delivery confirmation).
Sourcepub async fn send_ack(self) -> Result<(), RemoteSendError>
pub async fn send_ack(self) -> Result<(), RemoteSendError>
Sends the message and waits for delivery acknowledgment (reliable, slower).
Sourceimpl<A, M> RemoteTellRequest<'_, A, M, WithoutRequestTimeout>
impl<A, M> RemoteTellRequest<'_, A, M, WithoutRequestTimeout>
Sourcepub async fn try_send(self) -> Result<(), RemoteSendError>
pub async fn try_send(self) -> Result<(), RemoteSendError>
Tries to send the message fire-and-forget style, failing immediately if mailbox is full.
Sourcepub async fn try_send_ack(self) -> Result<(), RemoteSendError>
pub async fn try_send_ack(self) -> Result<(), RemoteSendError>
Tries to send the message with acknowledgment, failing immediately if mailbox is full.