pub struct TellRequest<'a, A, M, Tm>{ /* private fields */ }Expand description
A request to send a message to an actor without any reply.
This can be thought of as “fire and forget”.
Implementations
Sourceimpl<'a, A, M, Tm> TellRequest<'a, A, M, Tm>
impl<'a, A, M, Tm> TellRequest<'a, A, M, Tm>
Sourcepub fn mailbox_timeout(
self,
duration: Duration,
) -> TellRequest<'a, A, M, WithRequestTimeout>
pub fn mailbox_timeout( self, duration: Duration, ) -> TellRequest<'a, A, M, WithRequestTimeout>
Sets the timeout for waiting for the actors mailbox to have capacity.
Sourcepub fn send_after(
self,
duration: Duration,
) -> JoinHandle<Result<(), SendError<M>>>
pub fn send_after( self, duration: Duration, ) -> JoinHandle<Result<(), SendError<M>>>
Sends a message to the actor after a delay.
Returns a JoinHandle that can be used to cancel the scheduled send via
JoinHandle::abort. The handle can safely be ignored for fire-and-forget usage.
Awaiting the handle will block until the delay has elapsed and the message has been sent; this is rarely what you want.
Sourceimpl<A, M> TellRequest<'_, A, M, WithoutRequestTimeout>
impl<A, M> TellRequest<'_, A, M, WithoutRequestTimeout>